@@ -27,7 +27,7 @@ our @ISA = qw(Exporter);
 
 our @EXPORT_OK = qw( create_thumbnail );
 
-our $VERSION = 'v0.1.0';
+our $VERSION = 'v0.1.1';
 
 require XSLoader;
 XSLoader::load('Ithumb::XS', $VERSION);
@@ -38,9 +38,9 @@ __END__
 
 =head1 SYNOPSIS
 
-use Ithumb::XS;
+  use Ithumb::XS;
 
-Ithumb::XS::create_thumbnail('src.png', 100, 100, 'output.png');
+  Ithumb::XS::create_thumbnail('src.png', 100, 100, 'output.png');
 
 =head1 METHODS
 
@@ -48,9 +48,16 @@ Ithumb::XS::create_thumbnail('src.png', 100, 100, 'output.png');
 
 Creates a small copy (with cropping) of the image.
 
-  $source_image - full path to source image
-  $width - destination width
-  $height - destination height
-  $dst_image - full path to destionation result image
+=over 12
+
+=item C<$source_image> - full path to source image
+
+=item C<$width> - destination width
+
+=item C<$height> - destination height
+
+=item C<$dst_image> - full path to destionation result image
+  
+=back
 
 =cut
